@@ -366,11 +366,16 @@ e_book_query_ref (EBookQuery *q)
 	return q;
 }
 
+typedef EBookQuery * (* EBookQueryNAry) (gint nqs,
+                                         EBookQuery **qs,
+                                         gboolean unref);
+
 static ESExpResult *
-func_and (struct _ESExp *f,
-          gint argc,
-          struct _ESExpResult **argv,
-          gpointer data)
+func_n_ary (EBookQueryNAry make_query,
+            struct _ESExp *f,
+            gint argc,
+            struct _ESExpResult **argv,
+            gpointer data)
 {
 	GList **list = data;
 	ESExpResult *r;
@@ -389,8 +394,7 @@ func_and (struct _ESExp *f,
 			*list = g_list_delete_link(*list, list_head);
 		}
 
-		*list = g_list_prepend(*list,
-				       e_book_query_and (argc, qs, TRUE));
+		*list = g_list_prepend(*list, make_query (argc, qs, TRUE));
 
 		g_free (qs);
 	}
@@ -401,39 +405,22 @@ func_and (struct _ESExp *f,
 	return r;
 }
 
+static ESExpResult *
+func_and (struct _ESExp *f,
+          gint argc,
+          struct _ESExpResult **argv,
+          gpointer data)
+{
+	return func_n_ary (e_book_query_and, f, argc, argv, data);
+}
+
 static ESExpResult *
 func_or (struct _ESExp *f,
          gint argc,
          struct _ESExpResult **argv,
          gpointer data)
 {
-	GList **list = data;
-	ESExpResult *r;
-	EBookQuery **qs;
-
-	if (argc > 0) {
-		gint i;
-
-		qs = g_new0 (EBookQuery *, argc);
-
-		for (i = 0; i < argc; i++) {
-			GList *list_head = *list;
-			if (!list_head)
-				break;
-			qs[i] = list_head->data;
-			*list = g_list_delete_link(*list, list_head);
-		}
-
-		*list = g_list_prepend(*list,
-				       e_book_query_or (argc, qs, TRUE));
-
-		g_free (qs);
-	}
-
-	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.boolean = FALSE;
-
-	return r;
+	return func_n_ary (e_book_query_or, f, argc, argv, data);
 }
 
 static ESExpResult *
@@ -458,77 +445,8 @@ func_not (struct _ESExp *f,
 }
 
 static ESExpResult *
-func_contains (struct _ESExp *f,
-               gint argc,
-               struct _ESExpResult **argv,
-               gpointer data)
-{
-	GList **list = data;
-	ESExpResult *r;
-
-	if (argc == 2
-	    && argv[0]->type == ESEXP_RES_STRING
-	    && argv[1]->type == ESEXP_RES_STRING) {
-		gchar *propname = argv[0]->value.string;
-		gchar *str = argv[1]->value.string;
-
-		if (!strcmp (propname, "x-evolution-any-field")) {
-			*list = g_list_prepend (*list, e_book_query_any_field_contains (str));
-		}
-		else {
-			EContactField field = e_contact_field_id (propname);
-
-			if (field)
-				*list = g_list_prepend (*list, e_book_query_field_test (field,
-											E_BOOK_QUERY_CONTAINS,
-											str));
-			else
-				*list = g_list_prepend (*list, e_book_query_vcard_field_test (propname,
-											E_BOOK_QUERY_CONTAINS,
-											str));
-		}
-	}
-
-	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.boolean = FALSE;
-
-	return r;
-}
-
-static ESExpResult *
-func_is (struct _ESExp *f,
-         gint argc,
-         struct _ESExpResult **argv,
-         gpointer data)
-{
-	GList **list = data;
-	ESExpResult *r;
-
-	if (argc == 2
-	    && argv[0]->type == ESEXP_RES_STRING
-	    && argv[1]->type == ESEXP_RES_STRING) {
-		gchar *propname = argv[0]->value.string;
-		gchar *str = argv[1]->value.string;
-		EContactField field = e_contact_field_id (propname);
-
-		if (field)
-			*list = g_list_prepend (*list, e_book_query_field_test (field,
-										E_BOOK_QUERY_IS,
-										str));
-		else
-			*list = g_list_prepend (*list, e_book_query_vcard_field_test (propname,
-										E_BOOK_QUERY_IS,
-										str));
-	}
-
-	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.boolean = FALSE;
-
-	return r;
-}
-
-static ESExpResult *
-func_beginswith (struct _ESExp *f,
+func_field_test (EBookQueryTest op,
+                 struct _ESExp *f,
                  gint argc,
                  struct _ESExpResult **argv,
                  gpointer data)
@@ -541,16 +459,21 @@ func_beginswith (struct _ESExp *f,
 	    && argv[1]->type == ESEXP_RES_STRING) {
 		gchar *propname = argv[0]->value.string;
 		gchar *str = argv[1]->value.string;
-		EContactField field = e_contact_field_id (propname);
+		EBookQuery *q;
 
-		if (field)
-			*list = g_list_prepend (*list, e_book_query_field_test (field,
-										E_BOOK_QUERY_BEGINS_WITH,
-										str));
-		else
-			*list = g_list_prepend (*list, e_book_query_vcard_field_test (propname,
-										E_BOOK_QUERY_BEGINS_WITH,
-										str));
+		if (op == E_BOOK_QUERY_CONTAINS
+		    && strcmp (propname, "x-evolution-any-field") == 0) {
+			q = e_book_query_any_field_contains (str);
+		} else {
+			EContactField field = e_contact_field_id (propname);
+
+			if (field)
+				q = e_book_query_field_test (field, op, str);
+			else
+				q = e_book_query_vcard_field_test (propname, op, str);
+		}
+
+		*list = g_list_prepend (*list, q);
 	}
 
 	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
@@ -559,36 +482,67 @@ func_beginswith (struct _ESExp *f,
 	return r;
 }
 
+static ESExpResult *
+func_contains (struct _ESExp *f,
+               gint argc,
+               struct _ESExpResult **argv,
+               gpointer data)
+{
+	return func_field_test (E_BOOK_QUERY_CONTAINS, f, argc, argv, data);
+}
+
+static ESExpResult *
+func_is (struct _ESExp *f,
+         gint argc,
+         struct _ESExpResult **argv,
+         gpointer data)
+{
+	return func_field_test (E_BOOK_QUERY_IS, f, argc, argv, data);
+}
+
+static ESExpResult *
+func_beginswith (struct _ESExp *f,
+                 gint argc,
+                 struct _ESExpResult **argv,
+                 gpointer data)
+{
+	return func_field_test (E_BOOK_QUERY_BEGINS_WITH, f, argc, argv, data);
+}
+
 static ESExpResult *
 func_endswith (struct _ESExp *f,
                gint argc,
                struct _ESExpResult **argv,
                gpointer data)
 {
-	GList **list = data;
-	ESExpResult *r;
+	return func_field_test (E_BOOK_QUERY_ENDS_WITH, f, argc, argv, data);
+}
 
-	if (argc == 2
-	    && argv[0]->type == ESEXP_RES_STRING
-	    && argv[1]->type == ESEXP_RES_STRING) {
-		gchar *propname = argv[0]->value.string;
-		gchar *str = argv[1]->value.string;
-		EContactField field = e_contact_field_id (propname);
+static ESExpResult *
+func_eqphone (struct _ESExp *f,
+              gint argc,
+              struct _ESExpResult **argv,
+              gpointer data)
+{
+	return func_field_test (E_BOOK_QUERY_EQUALS_PHONE_NUMBER, f, argc, argv, data);
+}
 
-		if (field)
-			*list = g_list_prepend (*list, e_book_query_field_test (field,
-										E_BOOK_QUERY_ENDS_WITH,
-										str));
-		else
-			*list = g_list_prepend (*list, e_book_query_vcard_field_test (propname,
-										E_BOOK_QUERY_ENDS_WITH,
-										str));
-	}
+static ESExpResult *
+func_eqphone_national (struct _ESExp *f,
+                       gint argc,
+                       struct _ESExpResult **argv,
+                       gpointer data)
+{
+	return func_field_test (E_BOOK_QUERY_EQUALS_NATIONAL_PHONE_NUMBER, f, argc, argv, data);
+}
 
-	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.boolean = FALSE;
-
-	return r;
+static ESExpResult *
+func_eqphone_short (struct _ESExp *f,
+                    gint argc,
+                    struct _ESExpResult **argv,
+                    gpointer data)
+{
+	return func_field_test (E_BOOK_QUERY_EQUALS_SHORT_PHONE_NUMBER, f, argc, argv, data);
 }
 
 static ESExpResult *
@@ -651,6 +605,9 @@ static const struct {
 	{ "is", func_is, 0 },
 	{ "beginswith", func_beginswith, 0 },
 	{ "endswith", func_endswith, 0 },
+	{ "eqphone", func_eqphone, 0 },
+	{ "eqphone_national", func_eqphone_national, 0 },
+	{ "eqphone_short", func_eqphone_short, 0 },
 	{ "exists", func_exists, 0 },
 	{ "exists_vcard", func_exists_vcard, 0 }
 };
@@ -686,24 +643,21 @@ e_book_query_from_string (const gchar *query_string)
 	}
 
 	e_sexp_input_text (sexp, query_string, strlen (query_string));
-	e_sexp_parse (sexp);
+
+	if (e_sexp_parse (sexp) == -1) {
+		g_warning ("%s: Error in parsing: %s", G_STRFUNC, sexp->error);
+		return NULL;
+	}
 
 	r = e_sexp_eval (sexp);
 
 	e_sexp_result_free (sexp, r);
 	e_sexp_unref (sexp);
 
-	if (list) {
-		if (list->next) {
-			g_warning ("conversion to EBookQuery");
-			retval = NULL;
-			g_list_foreach (list, (GFunc) e_book_query_unref, NULL);
-		}
-		else {
-			retval = list->data;
-		}
-	}
-	else {
+	if (list && list->next == NULL) {
+		retval = list->data;
+	} else {
+		g_list_foreach (list, (GFunc) e_book_query_unref, NULL);
 		g_warning ("conversion to EBookQuery failed");
 		retval = NULL;
 	}
@@ -712,6 +666,29 @@ e_book_query_from_string (const gchar *query_string)
 	return retval;
 }
 
+static const gchar *
+field_test_name (EBookQueryTest field_test)
+{
+	switch (field_test) {
+	case E_BOOK_QUERY_IS:
+		return "is";
+	case E_BOOK_QUERY_CONTAINS:
+		return "contains";
+	case E_BOOK_QUERY_BEGINS_WITH:
+		return "beginswith";
+	case E_BOOK_QUERY_ENDS_WITH:
+		return "endswith";
+	case E_BOOK_QUERY_EQUALS_PHONE_NUMBER:
+		return "eqphone";
+	case E_BOOK_QUERY_EQUALS_NATIONAL_PHONE_NUMBER:
+		return "eqphone_national";
+	case E_BOOK_QUERY_EQUALS_SHORT_PHONE_NUMBER:
+		return "eqphone_short";
+	}
+
+	return NULL;
+}
+
 /**
  * e_book_query_to_string:
  * @q: an #EBookQuery
@@ -728,7 +705,7 @@ e_book_query_to_string (EBookQuery *q)
 	GString *encoded = g_string_new ("");
 	gint i;
 	gchar *s = NULL;
-	const gchar *cs;
+	const gchar *fn;
 
 	switch (q->type) {
 	case E_BOOK_QUERY_TYPE_AND:
@@ -762,21 +739,18 @@ e_book_query_to_string (EBookQuery *q)
 		}
 		break;
 	case E_BOOK_QUERY_TYPE_FIELD_TEST:
-		switch (q->query.field_test.test) {
-		case E_BOOK_QUERY_IS: cs = "is"; break;
-		case E_BOOK_QUERY_CONTAINS: cs = "contains"; break;
-		case E_BOOK_QUERY_BEGINS_WITH: cs = "beginswith"; break;
-		case E_BOOK_QUERY_ENDS_WITH: cs = "endswith"; break;
-		default:
-			g_assert_not_reached ();
-			break;
+		fn = field_test_name (q->query.field_test.test);
+
+		if (fn == NULL) {
+			g_string_free (str, TRUE);
+			g_warn_if_reached ();
+			return NULL;
 		}
 
 		e_sexp_encode_string (encoded, q->query.field_test.value);
 
 		g_string_append_printf (
-			str, "%s \"%s\" %s",
-			cs,
+			str, "%s \"%s\" %s", fn,
 			q->query.field_test.field_name,
 			encoded->str);
 		break;
