@@ -20,14 +20,30 @@ typedef struct EBookQuery EBookQuery;
  * @E_BOOK_QUERY_CONTAINS: check if a field contains the test value
  * @E_BOOK_QUERY_BEGINS_WITH: check if a field starts with the test value
  * @E_BOOK_QUERY_ENDS_WITH: check if a field ends with the test value
+ * @E_BOOK_QUERY_EQUALS_PHONE_NUMBER: check that a field and the test value
+ * match exactly when interpreted as phone number, that is after stripping
+ * formatting like dashes, dots and spaces. See E_PHONE_NUMBER_MATCH_EXACT.
+ * @E_BOOK_QUERY_EQUALS_NATIONAL_PHONE_NUMBER: check that a field and the
+ * test value match when interpreted as phone number, except for the
+ * (omitted) country code.
+ * @E_BOOK_QUERY_EQUALS_SHORT_PHONE_NUMBER: check that a field and the test
+ * value match is the sense that both values appear to be phone numbers,
+ * and one might be a part (suffix) of the other.
  *
  * The kind of test a query created by e_book_query_field_test() shall perform.
+ *
+ * See also: E_PHONE_NUMBER_MATCH_EXACT, E_PHONE_NUMBER_MATCH_NATIONAL and
+ * E_PHONE_NUMBER_MATCH_SHORT.
  **/
 typedef enum {
   E_BOOK_QUERY_IS,
   E_BOOK_QUERY_CONTAINS,
   E_BOOK_QUERY_BEGINS_WITH,
-  E_BOOK_QUERY_ENDS_WITH
+  E_BOOK_QUERY_ENDS_WITH,
+
+  E_BOOK_QUERY_EQUALS_PHONE_NUMBER,
+  E_BOOK_QUERY_EQUALS_NATIONAL_PHONE_NUMBER,
+  E_BOOK_QUERY_EQUALS_SHORT_PHONE_NUMBER
 
   /*
     Consider these "coming soon".
