@@ -92,15 +92,7 @@ G_DEFINE_TYPE_WITH_CODE (
 	EBook, e_book, G_TYPE_OBJECT,
 	G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE, e_book_initable_init))
 
-GQuark
-e_book_error_quark (void)
-{
-	static GQuark q = 0;
-	if (q == 0)
-		q = g_quark_from_static_string ("e-book-error-quark");
-
-	return q;
-}
+G_DEFINE_QUARK (e-book-error-quark, e_book_error)
 
 static void
 book_backend_died_cb (EClient *client,
@@ -1647,9 +1639,6 @@ get_book_view_reply (GObject *source_object,
 	if (excb != NULL)
 		excb (data->book, error, view, data->closure);
 
-	if (view != NULL)
-		g_object_unref (view);
-
 	if (error != NULL)
 		g_error_free (error);
 
@@ -1663,7 +1652,7 @@ get_book_view_reply (GObject *source_object,
  * @query: an #EBookQuery
  * @requested_fields: (element-type utf8): a #GList containing the names of fields to return, or NULL for all
  * @max_results: the maximum number of contacts to show (or 0 for all)
- * @cb: (scope call): a function to call when the operation finishes
+ * @cb: (scope async): a function to call when the operation finishes
  * @closure: data to pass to callback function
  *
  * Query @book with @query, creating a #EBookView with the fields
@@ -1710,7 +1699,7 @@ e_book_async_get_book_view (EBook *book,
  * @requested_fields: (allow-none) (element-type utf8): a #GList containing the names of fields to
  * return, or NULL for all
  * @max_results: the maximum number of contacts to show (or 0 for all)
- * @cb: (scope call): a function to call when the operation finishes
+ * @cb: (scope async): a function to call when the operation finishes
  * @closure: data to pass to callback function
  *
  * Query @book with @query, creating a #EBookView with the fields
