@@ -14,6 +14,9 @@
 
 #ifndef EDS_DISABLE_DEPRECATED
 
+/* Do not generate bindings. */
+#ifndef __GI_SCANNER__
+
 #ifndef __E_BOOK_H__
 #define __E_BOOK_H__
 
@@ -352,4 +355,6 @@ G_END_DECLS
 
 #endif /* __E_BOOK_H__ */
 
+#endif /* __GI_SCANNER__ */
+
 #endif /* EDS_DISABLE_DEPRECATED */
