@@ -14,7 +14,6 @@
 #include "e-data-book.h"
 #include "e-book-backend.h"
 
-#define EDB_OPENING_ERROR	e_data_book_create_error (E_DATA_BOOK_STATUS_BUSY, _("Cannot process, book backend is opening"))
 #define EDB_NOT_OPENED_ERROR	e_data_book_create_error (E_DATA_BOOK_STATUS_NOT_OPENED, NULL)
 
 #define E_BOOK_BACKEND_GET_PRIVATE(obj) \
@@ -27,7 +26,8 @@ struct _EBookBackendPrivate {
 	GMutex clients_mutex;
 	GList *clients;
 
-	gboolean opening, opened, readonly, removed, online;
+	gboolean opened, removed;
+	gboolean writable;
 
 	GMutex views_mutex;
 	GList *views;
@@ -39,7 +39,8 @@ struct _EBookBackendPrivate {
 enum {
 	PROP_0,
 	PROP_CACHE_DIR,
-	PROP_REGISTRY
+	PROP_REGISTRY,
+	PROP_WRITABLE
 };
 
 G_DEFINE_TYPE (EBookBackend, e_book_backend, E_TYPE_BACKEND)
@@ -77,9 +78,11 @@ book_backend_get_backend_property (EBookBackend *backend,
 	g_return_if_fail (prop_name != NULL);
 
 	if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_OPENED)) {
-		e_data_book_respond_get_backend_property (book, opid, NULL, e_book_backend_is_opened (backend) ? "TRUE" : "FALSE");
+		e_data_book_respond_get_backend_property (book, opid, NULL, "TRUE");
 	} else if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_OPENING)) {
-		e_data_book_respond_get_backend_property (book, opid, NULL, e_book_backend_is_opening (backend) ? "TRUE" : "FALSE");
+		e_data_book_respond_get_backend_property (book, opid, NULL, "FALSE");
+	} else if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_REVISION)) {
+		e_data_book_respond_get_backend_property (book, opid, NULL, "0");
 	} else if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_ONLINE)) {
 		e_data_book_respond_get_backend_property (book, opid, NULL, e_backend_get_online (E_BACKEND (backend)) ? "TRUE" : "FALSE");
 	} else if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_READONLY)) {
@@ -99,12 +102,7 @@ book_backend_set_backend_property (EBookBackend *backend,
                                    const gchar *prop_name,
                                    const gchar *prop_value)
 {
-	g_return_if_fail (backend != NULL);
-	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
-	g_return_if_fail (book != NULL);
-	g_return_if_fail (prop_name != NULL);
-
-	e_data_book_respond_set_backend_property (book, opid, e_data_book_create_error_fmt (E_DATA_BOOK_STATUS_NOT_SUPPORTED, _("Cannot change value of book property '%s'"), prop_name));
+	/* Do nothing. */
 }
 
 static void
@@ -135,6 +133,12 @@ book_backend_set_property (GObject *object,
 				E_BOOK_BACKEND (object),
 				g_value_get_object (value));
 			return;
+
+		case PROP_WRITABLE:
+			e_book_backend_set_writable (
+				E_BOOK_BACKEND (object),
+				g_value_get_boolean (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -158,6 +162,12 @@ book_backend_get_property (GObject *object,
 				value, e_book_backend_get_registry (
 				E_BOOK_BACKEND (object)));
 			return;
+
+		case PROP_WRITABLE:
+			g_value_set_boolean (
+				value, e_book_backend_get_writable (
+				E_BOOK_BACKEND (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -202,6 +212,16 @@ book_backend_finalize (GObject *object)
 	G_OBJECT_CLASS (e_book_backend_parent_class)->finalize (object);
 }
 
+static void
+book_backend_constructed (GObject *object)
+{
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (e_book_backend_parent_class)->constructed (object);
+
+	/* Initialize the "cache-dir" property. */
+	book_backend_set_default_cache_dir (E_BOOK_BACKEND (object));
+}
+
 static gboolean
 book_backend_authenticate_sync (EBackend *backend,
                                 ESourceAuthenticator *auth,
@@ -249,6 +269,7 @@ e_book_backend_class_init (EBookBackendClass *class)
 	object_class->get_property = book_backend_get_property;
 	object_class->dispose = book_backend_dispose;
 	object_class->finalize = book_backend_finalize;
+	object_class->constructed = book_backend_constructed;
 
 	backend_class = E_BACKEND_CLASS (class);
 	backend_class->authenticate_sync = book_backend_authenticate_sync;
@@ -279,6 +300,17 @@ e_book_backend_class_init (EBookBackendClass *class)
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT_ONLY |
 			G_PARAM_STATIC_STRINGS));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_WRITABLE,
+		g_param_spec_boolean (
+			"writable",
+			"Writable",
+			"Whether the backend will accept changes",
+			FALSE,
+			G_PARAM_READWRITE |
+			G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -358,6 +390,47 @@ e_book_backend_get_registry (EBookBackend *backend)
 	return backend->priv->registry;
 }
 
+/**
+ * e_book_backend_get_writable:
+ * @backend: an #EBookBackend
+ *
+ * Returns whether @backend will accept changes to its data content.
+ *
+ * Returns: whether @backend is writable
+ *
+ * Since: 3.8
+ **/
+gboolean
+e_book_backend_get_writable (EBookBackend *backend)
+{
+	g_return_val_if_fail (E_IS_BOOK_BACKEND (backend), FALSE);
+
+	return backend->priv->writable;
+}
+
+/**
+ * e_book_backend_set_writable:
+ * @backend: an #EBookBackend
+ * @writable: whether @backend is writable
+ *
+ * Sets whether @backend will accept changes to its data content.
+ *
+ * Since: 3.8
+ **/
+void
+e_book_backend_set_writable (EBookBackend *backend,
+                             gboolean writable)
+{
+	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
+
+	if (writable == backend->priv->writable)
+		return;
+
+	backend->priv->writable = writable;
+
+	g_object_notify (G_OBJECT (backend), "writable");
+}
+
 /**
  * e_book_backend_open:
  * @backend: an #EBookBackend
@@ -428,23 +501,10 @@ e_book_backend_open (EBookBackend *backend,
 	if (e_book_backend_is_opened (backend)) {
 		g_mutex_unlock (&backend->priv->clients_mutex);
 
-		e_data_book_report_readonly (book, backend->priv->readonly);
-		e_data_book_report_online (book, backend->priv->online);
-
-		e_book_backend_respond_opened (backend, book, opid, NULL);
-	} else if (e_book_backend_is_opening (backend)) {
-		g_mutex_unlock (&backend->priv->clients_mutex);
-
-		e_data_book_respond_open (book, opid, EDB_OPENING_ERROR);
+		e_data_book_respond_open (book, opid, NULL);
 	} else {
-		backend->priv->opening = TRUE;
 		g_mutex_unlock (&backend->priv->clients_mutex);
 
-		/* Subclasses may need to call e_book_backend_get_cache_dir() in
-		 * their open() methods, so get the "cache-dir" property
-		 * initialized before we call the method. */
-		book_backend_set_default_cache_dir (backend);
-
 		g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->open != NULL);
 
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->open) (backend, book, opid, cancellable, only_if_exists);
@@ -476,9 +536,7 @@ e_book_backend_refresh (EBookBackend *backend,
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 
-	if (e_book_backend_is_opening (backend))
-		e_data_book_respond_refresh (book, opid, EDB_OPENING_ERROR);
-	else if (!E_BOOK_BACKEND_GET_CLASS (backend)->refresh)
+	if (!E_BOOK_BACKEND_GET_CLASS (backend)->refresh)
 		e_data_book_respond_refresh (book, opid, e_data_book_create_error (E_DATA_BOOK_STATUS_NOT_SUPPORTED, NULL));
 	else if (!e_book_backend_is_opened (backend))
 		e_data_book_respond_refresh (book, opid, EDB_NOT_OPENED_ERROR);
@@ -512,9 +570,7 @@ e_book_backend_create_contacts (EBookBackend *backend,
 	g_return_if_fail (vcards);
 	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->create_contacts);
 
-	if (e_book_backend_is_opening (backend))
-		e_data_book_respond_create_contacts (book, opid, EDB_OPENING_ERROR, NULL);
-	else if (!e_book_backend_is_opened (backend))
+	if (!e_book_backend_is_opened (backend))
 		e_data_book_respond_create_contacts (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->create_contacts) (backend, book, opid, cancellable, vcards);
@@ -544,9 +600,7 @@ e_book_backend_remove_contacts (EBookBackend *backend,
 	g_return_if_fail (id_list);
 	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->remove_contacts);
 
-	if (e_book_backend_is_opening (backend))
-		e_data_book_respond_remove_contacts (book, opid, EDB_OPENING_ERROR, NULL);
-	else if (!e_book_backend_is_opened (backend))
+	if (!e_book_backend_is_opened (backend))
 		e_data_book_respond_remove_contacts (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->remove_contacts) (backend, book, opid, cancellable, id_list);
@@ -578,9 +632,7 @@ e_book_backend_modify_contacts (EBookBackend *backend,
 	g_return_if_fail (vcards);
 	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->modify_contacts);
 
-	if (e_book_backend_is_opening (backend))
-		e_data_book_respond_modify_contacts (book, opid, EDB_OPENING_ERROR, NULL);
-	else if (!e_book_backend_is_opened (backend))
+	if (!e_book_backend_is_opened (backend))
 		e_data_book_respond_modify_contacts (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->modify_contacts) (backend, book, opid, cancellable, vcards);
@@ -610,9 +662,7 @@ e_book_backend_get_contact (EBookBackend *backend,
 	g_return_if_fail (id);
 	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->get_contact);
 
-	if (e_book_backend_is_opening (backend))
-		e_data_book_respond_get_contact (book, opid, EDB_OPENING_ERROR, NULL);
-	else if (!e_book_backend_is_opened (backend))
+	if (!e_book_backend_is_opened (backend))
 		e_data_book_respond_get_contact (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->get_contact) (backend, book, opid, cancellable, id);
@@ -642,9 +692,7 @@ e_book_backend_get_contact_list (EBookBackend *backend,
 	g_return_if_fail (query);
 	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->get_contact_list);
 
-	if (e_book_backend_is_opening (backend))
-		e_data_book_respond_get_contact_list (book, opid, EDB_OPENING_ERROR, NULL);
-	else if (!e_book_backend_is_opened (backend))
+	if (!e_book_backend_is_opened (backend))
 		e_data_book_respond_get_contact_list (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->get_contact_list) (backend, book, opid, cancellable, query);
@@ -676,9 +724,7 @@ e_book_backend_get_contact_list_uids (EBookBackend *backend,
 	g_return_if_fail (query);
 	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->get_contact_list_uids);
 
-	if (e_book_backend_is_opening (backend))
-		e_data_book_respond_get_contact_list_uids (book, opid, EDB_OPENING_ERROR, NULL);
-	else if (!e_book_backend_is_opened (backend))
+	if (!e_book_backend_is_opened (backend))
 		e_data_book_respond_get_contact_list_uids (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->get_contact_list_uids) (backend, book, opid, cancellable, query);
@@ -815,9 +861,6 @@ e_book_backend_remove_client (EBookBackend *backend,
 	g_mutex_lock (&backend->priv->clients_mutex);
 	backend->priv->clients = g_list_remove (backend->priv->clients, book);
 
-	if (backend->priv->clients == NULL)
-		backend->priv->opening = FALSE;
-
 	g_mutex_unlock (&backend->priv->clients_mutex);
 
 	g_object_unref (backend);
@@ -942,6 +985,8 @@ e_book_backend_get_backend_property (EBookBackend *backend,
  * which fetching it doesn't overwrite.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: This function no longer does anything.
  **/
 void
 e_book_backend_set_backend_property (EBookBackend *backend,
@@ -951,13 +996,7 @@ e_book_backend_set_backend_property (EBookBackend *backend,
                                      const gchar *prop_name,
                                      const gchar *prop_value)
 {
-	g_return_if_fail (backend != NULL);
-	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
-	g_return_if_fail (prop_name != NULL);
-	g_return_if_fail (prop_value != NULL);
-	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->set_backend_property != NULL);
-
-	E_BOOK_BACKEND_GET_CLASS (backend)->set_backend_property (backend, book, opid, cancellable, prop_name, prop_value);
+	/* Do nothing. */
 }
 
 /**
@@ -992,7 +1031,10 @@ e_book_backend_is_opened (EBookBackend *backend)
  * every operation except of cancel and authenticate_user while
  * it is being opening.
  *
- * Returns: %TRUE if opening phase is in the effect, %FALSE otherwise.
+ * Returns: %FALSE always
+ *
+ * Deprecated: 3.8: This function is no longer relevant,
+ *                  and always returns %FALSE.
  *
  * Since: 3.2
  **/
@@ -1001,7 +1043,7 @@ e_book_backend_is_opening (EBookBackend *backend)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND (backend), FALSE);
 
-	return backend->priv->opening;
+	return FALSE;
 }
 
 /**
@@ -1010,7 +1052,7 @@ e_book_backend_is_opening (EBookBackend *backend)
  *
  * Checks if we can write to @backend.
  *
- * Returns: %TRUE if writeable, %FALSE if not.
+ * Returns: %TRUE if read-only, %FALSE if not.
  *
  * Since: 3.2
  **/
@@ -1019,7 +1061,7 @@ e_book_backend_is_readonly (EBookBackend *backend)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND (backend), FALSE);
 
-	return backend->priv->readonly;
+	return !e_book_backend_get_writable (backend);
 }
 
 /**
@@ -1197,23 +1239,16 @@ e_book_backend_notify_error (EBookBackend *backend,
  * Notifies all backend's clients about the current readonly state.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: Use e_book_backend_set_writable() instead.
  **/
 void
 e_book_backend_notify_readonly (EBookBackend *backend,
                                 gboolean is_readonly)
 {
-	EBookBackendPrivate *priv;
-	GList *clients;
-
-	priv = backend->priv;
-	priv->readonly = is_readonly;
-	g_mutex_lock (&priv->clients_mutex);
-
-	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
-		e_data_book_report_readonly (E_DATA_BOOK (clients->data), is_readonly);
-
-	g_mutex_unlock (&priv->clients_mutex);
+	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 
+	e_book_backend_set_writable (backend, !is_readonly);
 }
 
 /**
@@ -1225,22 +1260,16 @@ e_book_backend_notify_readonly (EBookBackend *backend,
  * Meant to be used by backend implementations.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: Use e_backend_set_online() instead.
  **/
 void
 e_book_backend_notify_online (EBookBackend *backend,
                               gboolean is_online)
 {
-	EBookBackendPrivate *priv;
-	GList *clients;
+	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 
-	priv = backend->priv;
-	priv->online = is_online;
-	g_mutex_lock (&priv->clients_mutex);
-
-	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
-		e_data_book_report_online (E_DATA_BOOK (clients->data), is_online);
-
-	g_mutex_unlock (&priv->clients_mutex);
+	e_backend_set_online (E_BACKEND (backend), is_online);
 }
 
 /**
@@ -1263,23 +1292,20 @@ e_book_backend_notify_online (EBookBackend *backend,
  * Meant to be used by backend implementations.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: Use e_data_book_respond_open() instead.
  **/
 void
 e_book_backend_notify_opened (EBookBackend *backend,
                               GError *error)
 {
 	EBookBackendPrivate *priv;
-	GList *clients;
 
 	priv = backend->priv;
 	g_mutex_lock (&priv->clients_mutex);
 
-	priv->opening = FALSE;
 	priv->opened = error == NULL;
 
-	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
-		e_data_book_report_opened (E_DATA_BOOK (clients->data), error);
-
 	g_mutex_unlock (&priv->clients_mutex);
 
 	if (error)
@@ -1333,6 +1359,8 @@ e_book_backend_notify_property_changed (EBookBackend *backend,
  * See e_book_backend_open() for more details how the opening phase works.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: Use e_data_book_respond_open() instead.
  **/
 void
 e_book_backend_respond_opened (EBookBackend *backend,
@@ -1340,16 +1368,10 @@ e_book_backend_respond_opened (EBookBackend *backend,
                                guint32 opid,
                                GError *error)
 {
-	GError *copy = NULL;
-
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (book != NULL);
 	g_return_if_fail (opid != 0);
 
-	if (error)
-		copy = g_error_copy (error);
-
-	e_book_backend_notify_opened (backend, copy);
 	e_data_book_respond_open (book, opid, error);
 }
