@@ -51,24 +51,6 @@
 	(G_TYPE_INSTANCE_GET_CLASS \
 	((obj), E_TYPE_BOOK_BACKEND, EBookBackendClass))
 
-/**
- * CLIENT_BACKEND_PROPERTY_OPENED:
- *
- * FIXME: Document me.
- *
- * Since: 3.2
- **/
-#define CLIENT_BACKEND_PROPERTY_OPENED			"opened"
-
-/**
- * CLIENT_BACKEND_PROPERTY_OPENING:
- *
- * FIXME: Document me.
- *
- * Since: 3.2
- **/
-#define CLIENT_BACKEND_PROPERTY_OPENING			"opening"
-
 /**
  * CLIENT_BACKEND_PROPERTY_ONLINE:
  *
@@ -154,6 +136,8 @@ struct _EBookBackendClass {
 						 guint32 opid,
 						 GCancellable *cancellable,
 						 const gchar *prop_name);
+
+	/* This method is deprecated. */
 	void		(*set_backend_property)	(EBookBackend *backend,
 						 EDataBook *book,
 						 guint32 opid,
@@ -222,6 +206,9 @@ void		e_book_backend_set_cache_dir	(EBookBackend *backend,
 						 const gchar *cache_dir);
 ESourceRegistry *
 		e_book_backend_get_registry	(EBookBackend *backend);
+gboolean	e_book_backend_get_writable	(EBookBackend *backend);
+void		e_book_backend_set_writable	(EBookBackend *backend,
+						 gboolean writable);
 
 gboolean	e_book_backend_add_client	(EBookBackend *backend,
 						 EDataBook *book);
@@ -229,7 +216,6 @@ void		e_book_backend_remove_client	(EBookBackend *backend,
 						 EDataBook *book);
 
 gboolean	e_book_backend_is_opened	(EBookBackend *backend);
-gboolean	e_book_backend_is_opening	(EBookBackend *backend);
 gboolean	e_book_backend_is_readonly	(EBookBackend *backend);
 gboolean	e_book_backend_is_removed	(EBookBackend *backend);
 
@@ -239,13 +225,6 @@ void		e_book_backend_get_backend_property
 						 guint32 opid,
 						 GCancellable *cancellable,
 						 const gchar *prop_name);
-void		e_book_backend_set_backend_property
-						(EBookBackend *backend,
-						 EDataBook *book,
-						 guint32 opid,
-						 GCancellable *cancellable,
-						 const gchar *prop_name,
-						 const gchar *prop_value);
 
 void		e_book_backend_open		(EBookBackend *backend,
 						 EDataBook *book,
@@ -306,12 +285,6 @@ void		e_book_backend_notify_complete	(EBookBackend *backend);
 
 void		e_book_backend_notify_error	(EBookBackend *backend,
 						 const gchar *message);
-void		e_book_backend_notify_readonly	(EBookBackend *backend,
-						 gboolean is_readonly);
-void		e_book_backend_notify_online	(EBookBackend *backend,
-						 gboolean is_online);
-void		e_book_backend_notify_opened	(EBookBackend *backend,
-						 GError *error);
 void		e_book_backend_notify_property_changed
 						(EBookBackend *backend,
 						 const gchar *prop_name,
@@ -323,12 +296,31 @@ void		e_book_backend_sync		(EBookBackend *backend);
 void		e_book_backend_set_is_removed	(EBookBackend *backend,
 						 gboolean is_removed);
 
-void		e_book_backend_respond_opened	(EBookBackend *backend,
-						 EDataBook *book,
-						 guint32 opid,
-						 GError *error);
-
 #ifndef EDS_DISABLE_DEPRECATED
+/**
+ * CLIENT_BACKEND_PROPERTY_OPENED:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ *
+ * Deprecated: 3.8: Clients don't need to care if they're fully opened
+ *                  anymore.  This property will always return %TRUE.
+ **/
+#define CLIENT_BACKEND_PROPERTY_OPENED			"opened"
+
+/**
+ * CLIENT_BACKEND_PROPERTY_OPENING:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ *
+ * Deprecated: 3.8: Clients don't need to care if they're fully opened
+ *                  anymore.  This property will always return %FALSE.
+ **/
+#define CLIENT_BACKEND_PROPERTY_OPENING			"opening"
+
 /**
  * BOOK_BACKEND_PROPERTY_SUPPORTED_AUTH_METHODS:
  *
@@ -338,10 +330,28 @@ void		e_book_backend_respond_opened	(EBookBackend *backend,
  **/
 #define BOOK_BACKEND_PROPERTY_SUPPORTED_AUTH_METHODS	"supported-auth-methods"
 
+gboolean	e_book_backend_is_opening	(EBookBackend *backend);
+void		e_book_backend_set_backend_property
+						(EBookBackend *backend,
+						 EDataBook *book,
+						 guint32 opid,
+						 GCancellable *cancellable,
+						 const gchar *prop_name,
+						 const gchar *prop_value);
 void		e_book_backend_foreach_view	(EBookBackend *backend,
 						 gboolean (*callback) (EDataBookView *view,
 								       gpointer user_data),
 								       gpointer user_data);
+void		e_book_backend_notify_opened	(EBookBackend *backend,
+						 GError *error);
+void		e_book_backend_notify_readonly	(EBookBackend *backend,
+						 gboolean is_readonly);
+void		e_book_backend_notify_online	(EBookBackend *backend,
+						 gboolean is_online);
+void		e_book_backend_respond_opened	(EBookBackend *backend,
+						 EDataBook *book,
+						 guint32 opid,
+						 GError *error);
 #endif /* EDS_DISABLE_DEPRECATED */
 
 G_END_DECLS
