@@ -163,10 +163,6 @@ void		e_data_book_respond_get_backend_property
 						 guint32 opid,
 						 GError *error,
 						 const gchar *prop_value);
-void		e_data_book_respond_set_backend_property
-						(EDataBook *book,
-						 guint32 opid,
-						 GError *error);
 void		e_data_book_respond_create_contacts
 						(EDataBook *book,
 						 guint32 opid,
@@ -199,12 +195,6 @@ void		e_data_book_respond_get_contact_list_uids
 
 void		e_data_book_report_error	(EDataBook *book,
 						 const gchar *message);
-void		e_data_book_report_readonly	(EDataBook *book,
-						 gboolean readonly);
-void		e_data_book_report_online	(EDataBook *book,
-						 gboolean is_online);
-void		e_data_book_report_opened	(EDataBook *book,
-						 const GError *error);
 void		e_data_book_report_backend_property_changed
 						(EDataBook *book,
 						 const gchar *prop_name,
@@ -213,6 +203,19 @@ void		e_data_book_report_backend_property_changed
 gchar *		e_data_book_string_slist_to_comma_string
 						(const GSList *strings);
 
+#ifndef EDS_DISABLE_DEPRECATED
+void		e_data_book_respond_set_backend_property
+						(EDataBook *book,
+						 guint32 opid,
+						 GError *error);
+void		e_data_book_report_opened	(EDataBook *book,
+						 const GError *error);
+void		e_data_book_report_readonly	(EDataBook *book,
+						 gboolean readonly);
+void		e_data_book_report_online	(EDataBook *book,
+						 gboolean is_online);
+#endif /* EDS_DISABLE_DEPRECATED */
+
 G_END_DECLS
 
 #endif /* E_DATA_BOOK_H */
