@@ -33,7 +33,6 @@
 	((obj), E_TYPE_CAL_BACKEND, ECalBackendPrivate))
 
 #define EDC_ERROR(_code)	e_data_cal_create_error (_code, NULL)
-#define EDC_OPENING_ERROR	e_data_cal_create_error (Busy, _("Cannot process, calendar backend is opening"))
 #define EDC_NOT_OPENED_ERROR	e_data_cal_create_error (NotOpened, NULL)
 
 /* Private part of the CalBackend structure */
@@ -43,7 +42,8 @@ struct _ECalBackendPrivate {
 	/* The kind of components for this backend */
 	icalcomponent_kind kind;
 
-	gboolean opening, opened, readonly, removed;
+	gboolean opened, removed;
+	gboolean writable;
 
 	gchar *cache_dir;
 
@@ -67,7 +67,8 @@ enum {
 	PROP_0,
 	PROP_CACHE_DIR,
 	PROP_KIND,
-	PROP_REGISTRY
+	PROP_REGISTRY,
+	PROP_WRITABLE
 };
 
 /* Forward Declarations */
@@ -143,9 +144,11 @@ cal_backend_get_backend_property (ECalBackend *backend,
 	g_return_if_fail (prop_name != NULL);
 
 	if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_OPENED)) {
-		e_data_cal_respond_get_backend_property (cal, opid, NULL, e_cal_backend_is_opened (backend) ? "TRUE" : "FALSE");
+		e_data_cal_respond_get_backend_property (cal, opid, NULL, "TRUE");
 	} else if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_OPENING)) {
-		e_data_cal_respond_get_backend_property (cal, opid, NULL, e_cal_backend_is_opening (backend) ? "TRUE" : "FALSE");
+		e_data_cal_respond_get_backend_property (cal, opid, NULL, "FALSE");
+	} else if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_REVISION)) {
+		e_data_cal_respond_get_backend_property (cal, opid, NULL, "0");
 	} else if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_ONLINE)) {
 		e_data_cal_respond_get_backend_property (cal, opid, NULL, e_backend_get_online (E_BACKEND (backend)) ? "TRUE" : "FALSE");
 	} else if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_READONLY)) {
@@ -165,12 +168,7 @@ cal_backend_set_backend_property (ECalBackend *backend,
                                   const gchar *prop_name,
                                   const gchar *prop_value)
 {
-	g_return_if_fail (backend != NULL);
-	g_return_if_fail (E_IS_CAL_BACKEND (backend));
-	g_return_if_fail (cal != NULL);
-	g_return_if_fail (prop_name != NULL);
-
-	e_data_cal_respond_set_backend_property (cal, opid, e_data_cal_create_error_fmt (NotSupported, _("Cannot change value of calendar property '%s'"), prop_name));
+	/* Do nothing. */
 }
 
 static void
@@ -214,6 +212,12 @@ cal_backend_set_property (GObject *object,
 				E_CAL_BACKEND (object),
 				g_value_get_object (value));
 			return;
+
+		case PROP_WRITABLE:
+			e_cal_backend_set_writable (
+				E_CAL_BACKEND (object),
+				g_value_get_boolean (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -243,6 +247,12 @@ cal_backend_get_property (GObject *object,
 				value, e_cal_backend_get_registry (
 				E_CAL_BACKEND (object)));
 			return;
+
+		case PROP_WRITABLE:
+			g_value_set_boolean (
+				value, e_cal_backend_get_writable (
+				E_CAL_BACKEND (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -292,9 +302,11 @@ cal_backend_finalize (GObject *object)
 static void
 cal_backend_constructed (GObject *object)
 {
-	cal_backend_set_default_cache_dir (E_CAL_BACKEND (object));
-
+	/* Chain up to parent's constructed() method. */
 	G_OBJECT_CLASS (e_cal_backend_parent_class)->constructed (object);
+
+	/* Initialize the "cache-dir" property. */
+	cal_backend_set_default_cache_dir (E_CAL_BACKEND (object));
 }
 
 static gboolean
@@ -512,6 +524,17 @@ e_cal_backend_class_init (ECalBackendClass *class)
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT_ONLY |
 			G_PARAM_STATIC_STRINGS));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_WRITABLE,
+		g_param_spec_boolean (
+			"writable",
+			"Writable",
+			"Whether the backend will accept changes",
+			FALSE,
+			G_PARAM_READWRITE |
+			G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -543,8 +566,6 @@ e_cal_backend_init (ECalBackend *backend)
 
 	backend->priv->zone_cache = zone_cache;
 	g_mutex_init (&backend->priv->zone_cache_lock);
-
-	backend->priv->readonly = TRUE;
 }
 
 /**
@@ -581,6 +602,47 @@ e_cal_backend_get_registry (ECalBackend *backend)
 	return backend->priv->registry;
 }
 
+/**
+ * e_cal_backend_get_writable:
+ * @backend: an #ECalBackend
+ *
+ * Returns whether @backend will accept changes to its data content.
+ *
+ * Returns: whether @backend is writable
+ *
+ * Since: 3.8
+ **/
+gboolean
+e_cal_backend_get_writable (ECalBackend *backend)
+{
+	g_return_val_if_fail (E_IS_CAL_BACKEND (backend), FALSE);
+
+	return backend->priv->writable;
+}
+
+/**
+ * e_cal_backend_set_writable:
+ * @backend: an #ECalBackend
+ * @writable: whether @backend is writable
+ *
+ * Sets whether @backend will accept changes to its data content.
+ *
+ * Since: 3.8
+ **/
+void
+e_cal_backend_set_writable (ECalBackend *backend,
+                            gboolean writable)
+{
+	g_return_if_fail (E_IS_CAL_BACKEND (backend));
+
+	if (writable == backend->priv->writable)
+		return;
+
+	backend->priv->writable = writable;
+
+	g_object_notify (G_OBJECT (backend), "writable");
+}
+
 /**
  * e_cal_backend_is_opened:
  * @backend: an #ECalBackend
@@ -613,16 +675,19 @@ e_cal_backend_is_opened (ECalBackend *backend)
  * every operation except of cancel and authenticate_user while
  * it is being opening.
  *
- * Returns: %TRUE if opening phase is in the effect, %FALSE otherwise.
+ * Returns: %FALSE always
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: This function is no longer relevant,
+ *                  and always returns %FALSE.
  **/
 gboolean
 e_cal_backend_is_opening (ECalBackend *backend)
 {
 	g_return_val_if_fail (E_IS_CAL_BACKEND (backend), FALSE);
 
-	return backend->priv->opening;
+	return FALSE;
 }
 
 /**
@@ -639,7 +704,7 @@ e_cal_backend_is_readonly (ECalBackend *backend)
 {
 	g_return_val_if_fail (E_IS_CAL_BACKEND (backend), FALSE);
 
-	return backend->priv->readonly;
+	return !e_cal_backend_get_writable (backend);
 }
 
 /**
@@ -798,6 +863,8 @@ e_cal_backend_get_backend_property (ECalBackend *backend,
  * which fetching it doesn't overwrite.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: This function no longer does anything.
  **/
 void
 e_cal_backend_set_backend_property (ECalBackend *backend,
@@ -807,13 +874,7 @@ e_cal_backend_set_backend_property (ECalBackend *backend,
                                     const gchar *prop_name,
                                     const gchar *prop_value)
 {
-	g_return_if_fail (backend != NULL);
-	g_return_if_fail (E_IS_CAL_BACKEND (backend));
-	g_return_if_fail (prop_name != NULL);
-	g_return_if_fail (prop_value != NULL);
-	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->set_backend_property != NULL);
-
-	(* E_CAL_BACKEND_GET_CLASS (backend)->set_backend_property) (backend, cal, opid, cancellable, prop_name, prop_value);
+	/* Do nothing. */
 }
 
 static void
@@ -871,9 +932,6 @@ e_cal_backend_remove_client_private (ECalBackend *backend,
 	g_mutex_lock (&backend->priv->clients_mutex);
 	backend->priv->clients = g_list_remove (backend->priv->clients, cal);
 
-	if (backend->priv->clients == NULL)
-		backend->priv->opening = FALSE;
-
 	g_mutex_unlock (&backend->priv->clients_mutex);
 
 	g_object_unref (backend);
@@ -1102,22 +1160,10 @@ e_cal_backend_open (ECalBackend *backend,
 	g_mutex_lock (&backend->priv->clients_mutex);
 
 	if (e_cal_backend_is_opened (backend)) {
-		gboolean online;
-
 		g_mutex_unlock (&backend->priv->clients_mutex);
 
-		e_data_cal_report_readonly (cal, backend->priv->readonly);
-
-		online = e_backend_get_online (E_BACKEND (backend));
-		e_data_cal_report_online (cal, online);
-
-		e_cal_backend_respond_opened (backend, cal, opid, NULL);
-	} else if (e_cal_backend_is_opening (backend)) {
-		g_mutex_unlock (&backend->priv->clients_mutex);
-
-		e_data_cal_respond_open (cal, opid, EDC_OPENING_ERROR);
+		e_data_cal_respond_open (cal, opid, NULL);
 	} else {
-		backend->priv->opening = TRUE;
 		g_mutex_unlock (&backend->priv->clients_mutex);
 
 		(* E_CAL_BACKEND_GET_CLASS (backend)->open) (backend, cal, opid, cancellable, only_if_exists);
@@ -1149,9 +1195,7 @@ e_cal_backend_refresh (ECalBackend *backend,
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_refresh (cal, opid, EDC_OPENING_ERROR);
-	else if (!E_CAL_BACKEND_GET_CLASS (backend)->refresh)
+	if (!E_CAL_BACKEND_GET_CLASS (backend)->refresh)
 		e_data_cal_respond_refresh (cal, opid, EDC_ERROR (UnsupportedMethod));
 	else if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_refresh (cal, opid, EDC_NOT_OPENED_ERROR);
@@ -1185,9 +1229,7 @@ e_cal_backend_get_object (ECalBackend *backend,
 	g_return_if_fail (uid != NULL);
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->get_object != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_get_object (cal, opid, EDC_OPENING_ERROR, NULL);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_get_object (cal, opid, EDC_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->get_object) (backend, cal, opid, cancellable, uid, rid);
@@ -1215,9 +1257,7 @@ e_cal_backend_get_object_list (ECalBackend *backend,
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->get_object_list != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_get_object_list (cal, opid, EDC_OPENING_ERROR, NULL);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_get_object_list (cal, opid, EDC_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->get_object_list) (backend, cal, opid, cancellable, sexp);
@@ -1252,9 +1292,7 @@ e_cal_backend_get_free_busy (ECalBackend *backend,
 	g_return_if_fail (start <= end);
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->get_free_busy != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_get_free_busy (cal, opid, EDC_OPENING_ERROR);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_get_free_busy (cal, opid, EDC_NOT_OPENED_ERROR);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->get_free_busy) (backend, cal, opid, cancellable, users, start, end);
@@ -1284,9 +1322,7 @@ e_cal_backend_create_objects (ECalBackend *backend,
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (calobjs != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_create_objects (cal, opid, EDC_OPENING_ERROR, NULL, NULL);
-	else if (!E_CAL_BACKEND_GET_CLASS (backend)->create_objects)
+	if (!E_CAL_BACKEND_GET_CLASS (backend)->create_objects)
 		e_data_cal_respond_create_objects (cal, opid, EDC_ERROR (UnsupportedMethod), NULL, NULL);
 	else if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_create_objects (cal, opid, EDC_NOT_OPENED_ERROR, NULL, NULL);
@@ -1314,15 +1350,13 @@ e_cal_backend_modify_objects (ECalBackend *backend,
                               guint32 opid,
                               GCancellable *cancellable,
                               const GSList *calobjs,
-                              CalObjModType mod)
+                              ECalObjModType mod)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (calobjs != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_modify_objects (cal, opid, EDC_OPENING_ERROR, NULL, NULL);
-	else if (!E_CAL_BACKEND_GET_CLASS (backend)->modify_objects)
+	if (!E_CAL_BACKEND_GET_CLASS (backend)->modify_objects)
 		e_data_cal_respond_modify_objects (cal, opid, EDC_ERROR (UnsupportedMethod), NULL, NULL);
 	else if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_modify_objects (cal, opid, EDC_NOT_OPENED_ERROR, NULL, NULL);
@@ -1351,16 +1385,14 @@ e_cal_backend_remove_objects (ECalBackend *backend,
                               guint32 opid,
                               GCancellable *cancellable,
                               const GSList *ids,
-                              CalObjModType mod)
+                              ECalObjModType mod)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (ids != NULL);
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->remove_objects != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_remove_objects (cal, opid, EDC_OPENING_ERROR, NULL, NULL, NULL);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_remove_objects (cal, opid, EDC_NOT_OPENED_ERROR, NULL, NULL, NULL);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->remove_objects) (backend, cal, opid, cancellable, ids, mod);
@@ -1389,9 +1421,7 @@ e_cal_backend_receive_objects (ECalBackend *backend,
 	g_return_if_fail (calobj != NULL);
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->receive_objects != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_receive_objects (cal, opid, EDC_OPENING_ERROR);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_receive_objects (cal, opid, EDC_NOT_OPENED_ERROR);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->receive_objects) (backend, cal, opid, cancellable, calobj);
@@ -1420,9 +1450,7 @@ e_cal_backend_send_objects (ECalBackend *backend,
 	g_return_if_fail (calobj != NULL);
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->send_objects != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_send_objects (cal, opid, EDC_OPENING_ERROR, NULL, NULL);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_send_objects (cal, opid, EDC_NOT_OPENED_ERROR, NULL, NULL);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->send_objects) (backend, cal, opid, cancellable, calobj);
@@ -1456,9 +1484,7 @@ e_cal_backend_get_attachment_uris (ECalBackend *backend,
 	g_return_if_fail (uid != NULL);
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->get_attachment_uris != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_get_attachment_uris (cal, opid, EDC_OPENING_ERROR, NULL);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_get_attachment_uris (cal, opid, EDC_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->get_attachment_uris) (backend, cal, opid, cancellable, uid, rid);
@@ -1492,9 +1518,7 @@ e_cal_backend_discard_alarm (ECalBackend *backend,
 	g_return_if_fail (uid != NULL);
 	g_return_if_fail (auid != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_discard_alarm (cal, opid, EDC_OPENING_ERROR);
-	else if (!E_CAL_BACKEND_GET_CLASS (backend)->discard_alarm)
+	if (!E_CAL_BACKEND_GET_CLASS (backend)->discard_alarm)
 		e_data_cal_respond_discard_alarm (cal, opid, e_data_cal_create_error (NotSupported, NULL));
 	else if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_discard_alarm (cal, opid, EDC_NOT_OPENED_ERROR);
@@ -1527,9 +1551,7 @@ e_cal_backend_get_timezone (ECalBackend *backend,
 	g_return_if_fail (tzid != NULL);
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->get_timezone != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_get_timezone (cal, opid, EDC_OPENING_ERROR, NULL);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_get_timezone (cal, opid, EDC_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->get_timezone) (backend, cal, opid, cancellable, tzid);
@@ -1557,9 +1579,7 @@ e_cal_backend_add_timezone (ECalBackend *backend,
 	g_return_if_fail (tzobject != NULL);
 	g_return_if_fail (E_CAL_BACKEND_GET_CLASS (backend)->add_timezone != NULL);
 
-	if (e_cal_backend_is_opening (backend))
-		e_data_cal_respond_add_timezone (cal, opid, EDC_OPENING_ERROR);
-	else if (!e_cal_backend_is_opened (backend))
+	if (!e_cal_backend_is_opened (backend))
 		e_data_cal_respond_add_timezone (cal, opid, EDC_NOT_OPENED_ERROR);
 	else
 		(* E_CAL_BACKEND_GET_CLASS (backend)->add_timezone) (backend, cal, opid, cancellable, tzobject);
@@ -1813,28 +1833,16 @@ e_cal_backend_notify_error (ECalBackend *backend,
  *
  * Notifies all backend's clients about the current readonly state.
  * Meant to be used by backend implementations.
+ *
+ * Deprecated: 3.8: Use e_cal_backend_set_writable() instead.
  **/
 void
 e_cal_backend_notify_readonly (ECalBackend *backend,
                                gboolean is_readonly)
 {
-	ECalBackendPrivate *priv;
-	GList *l;
+	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 
-	priv = backend->priv;
-	priv->readonly = is_readonly;
-
-	if (priv->notification_proxy) {
-		e_cal_backend_notify_readonly (priv->notification_proxy, is_readonly);
-		return;
-	}
-
-	g_mutex_lock (&priv->clients_mutex);
-
-	for (l = priv->clients; l; l = l->next)
-		e_data_cal_report_readonly (l->data, is_readonly);
-
-	g_mutex_unlock (&priv->clients_mutex);
+	e_cal_backend_set_writable (backend, !is_readonly);
 }
 
 /**
@@ -1846,27 +1854,16 @@ e_cal_backend_notify_readonly (ECalBackend *backend,
  * Meant to be used by backend implementations.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: Use e_backend_set_online() instead.
  **/
 void
 e_cal_backend_notify_online (ECalBackend *backend,
                              gboolean is_online)
 {
-	ECalBackendPrivate *priv;
-	GList *clients;
+	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 
-	priv = backend->priv;
-
-	if (priv->notification_proxy) {
-		e_cal_backend_notify_online (priv->notification_proxy, is_online);
-		return;
-	}
-
-	g_mutex_lock (&priv->clients_mutex);
-
-	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
-		e_data_cal_report_online (E_DATA_CAL (clients->data), is_online);
-
-	g_mutex_unlock (&priv->clients_mutex);
+	e_backend_set_online (E_BACKEND (backend), is_online);
 }
 
 /**
@@ -1889,23 +1886,20 @@ e_cal_backend_notify_online (ECalBackend *backend,
  * Meant to be used by backend implementations.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: Use e_data_cal_respond_open() instead.
  **/
 void
 e_cal_backend_notify_opened (ECalBackend *backend,
                              GError *error)
 {
 	ECalBackendPrivate *priv;
-	GList *clients;
 
 	priv = backend->priv;
 	g_mutex_lock (&priv->clients_mutex);
 
-	priv->opening = FALSE;
 	priv->opened = error == NULL;
 
-	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
-		e_data_cal_report_opened (E_DATA_CAL (clients->data), error);
-
 	g_mutex_unlock (&priv->clients_mutex);
 
 	if (error)
@@ -1959,6 +1953,8 @@ e_cal_backend_notify_property_changed (ECalBackend *backend,
  * See e_cal_backend_open() for more details how the opening phase works.
  *
  * Since: 3.2
+ *
+ * Deprecated: 3.8: Use e_data_book_respond_open() instead.
  **/
 void
 e_cal_backend_respond_opened (ECalBackend *backend,
@@ -1966,17 +1962,11 @@ e_cal_backend_respond_opened (ECalBackend *backend,
                               guint32 opid,
                               GError *error)
 {
-	GError *copy = NULL;
-
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (cal != NULL);
 	g_return_if_fail (opid != 0);
 
-	if (error)
-		copy = g_error_copy (error);
-
-	e_cal_backend_notify_opened (backend, copy);
 	e_data_cal_respond_open (cal, opid, error);
 }
 
