@@ -237,6 +237,9 @@ camel_junk_status_get_type (void)
 	
 	if (the_type == 0) {
 		static const GEnumValue values[] = {
+			{ CAMEL_JUNK_STATUS_ERROR,
+			  "CAMEL_JUNK_STATUS_ERROR",
+			  "error" },
 			{ CAMEL_JUNK_STATUS_INCONCLUSIVE,
 			  "CAMEL_JUNK_STATUS_INCONCLUSIVE",
 			  "inconclusive" },
