@@ -361,34 +361,43 @@ get_folder_offline (CamelStore *store,
 	CamelFolder *new_folder = NULL;
 	CamelStoreInfo *si;
 	CamelService *service;
+	CamelStoreSummary *summary;
 	const gchar *user_cache_dir;
+	gboolean is_inbox;
 
 	service = CAMEL_SERVICE (store);
 	user_cache_dir = camel_service_get_user_cache_dir (service);
 
-	si = camel_store_summary_path ((CamelStoreSummary *) imapx_store->summary, folder_name);
-	if (!si && g_ascii_strcasecmp (folder_name, "INBOX") == 0)
-		si = (CamelStoreInfo *) camel_imapx_store_summary_full_name (imapx_store->summary, folder_name);
-	if (si) {
-		gchar *folder_dir, *storage_path;
+	summary = CAMEL_STORE_SUMMARY (imapx_store->summary);
+	si = camel_store_summary_path (summary, folder_name);
+	is_inbox = (g_ascii_strcasecmp (folder_name, "INBOX") == 0);
 
-		storage_path = g_build_filename (user_cache_dir, "folders", NULL);
-		/* Note: Although the INBOX is defined to be case-insensitive in the IMAP RFC
-		 * it is still up to the server how to acutally name it in a LIST response. Since
-		 * we stored the name as the server provided it us in the summary we take that name
-		 * to look up the folder.
-		 * But for the on-disk cache we do always capitalize the Inbox no matter what the
-		 * server provided.
+	if (si == NULL && is_inbox)
+		si = (CamelStoreInfo *) camel_imapx_store_summary_full_name (
+			imapx_store->summary, folder_name);
+
+	if (si != NULL) {
+		gchar *base_dir;
+		gchar *folder_dir;
+
+		/* Note: Although the INBOX is defined to be case-insensitive
+		 *       in the IMAP RFC, it is still up to the server how to
+		 *       acutally name it in a LIST response. Since we stored
+		 *       the name as the server provided it us in the summary
+		 *       we take that name to look up the folder.
+		 *
+		 *       But for the on-disk cache we always capitalize the
+		 *       Inbox no matter what the server provided.
 		 */
+		base_dir = g_build_filename (user_cache_dir, "folders", NULL);
 		folder_dir = imapx_path_to_physical (
-			storage_path,
-			g_ascii_strcasecmp (folder_name, "INBOX") == 0 ? "INBOX" : folder_name);
-		g_free (storage_path);
-
-		new_folder = camel_imapx_folder_new (store, folder_dir, folder_name, error);
-
+			base_dir, is_inbox ? "INBOX" : folder_name);
+		new_folder = camel_imapx_folder_new (
+			store, folder_dir, folder_name, error);
 		g_free (folder_dir);
-		camel_store_summary_info_free ((CamelStoreSummary *) imapx_store->summary, si);
+		g_free (base_dir);
+
+		camel_store_summary_info_free (summary, si);
 	} else {
 		g_set_error (
 			error, CAMEL_STORE_ERROR,
@@ -1250,16 +1259,74 @@ imapx_store_get_folder_sync (CamelStore *store,
                              GError **error)
 {
 	CamelFolder *folder;
+	CamelSettings *settings;
+	gboolean use_real_junk_path = FALSE;
+	gboolean use_real_trash_path = FALSE;
 
-	folder = get_folder_offline (store, folder_name, flags, NULL);
-	if (folder == NULL) {
-		g_set_error (
-			error, CAMEL_STORE_ERROR,
-			CAMEL_STORE_ERROR_NO_FOLDER,
-			_("No such folder: %s"), folder_name);
-		return NULL;
+	folder = get_folder_offline (store, folder_name, flags, error);
+
+	/* Configure the folder flags according to IMAPX settings.
+	 *
+	 * XXX Since this is only done when the folder is first created,
+	 *     a restart is required to pick up changes to real Junk/Trash
+	 *     folder settings.  Need to think of a better way.
+	 *
+	 *     Perhaps have CamelStoreSettings grow junk and trash path
+	 *     string properties, and eliminate the CAMEL_FOLDER_IS_JUNK
+	 *     and CAMEL_FOLDER_IS_TRASH flags.  Then add functions like
+	 *     camel_folder_is_junk() and camel_folder_is_trash(), which
+	 *     compare their own full name against CamelStoreSettings.
+	 *
+	 *     Something to think about...
+	 */
+
+	settings = camel_service_ref_settings (CAMEL_SERVICE (store));
+
+	if (folder != NULL) {
+		use_real_junk_path =
+			camel_imapx_settings_get_use_real_junk_path (
+			CAMEL_IMAPX_SETTINGS (settings));
+		use_real_trash_path =
+			camel_imapx_settings_get_use_real_trash_path (
+			CAMEL_IMAPX_SETTINGS (settings));
 	}
 
+	if (use_real_junk_path) {
+		gchar *real_junk_path;
+
+		real_junk_path =
+			camel_imapx_settings_dup_real_junk_path (
+			CAMEL_IMAPX_SETTINGS (settings));
+
+		/* So we can safely compare strings. */
+		if (real_junk_path == NULL)
+			real_junk_path = g_strdup ("");
+
+		if (g_ascii_strcasecmp (real_junk_path, folder_name) == 0)
+			folder->folder_flags |= CAMEL_FOLDER_IS_JUNK;
+
+		g_free (real_junk_path);
+	}
+
+	if (use_real_trash_path) {
+		gchar *real_trash_path;
+
+		real_trash_path =
+			camel_imapx_settings_dup_real_trash_path (
+			CAMEL_IMAPX_SETTINGS (settings));
+
+		/* So we can safely compare strings. */
+		if (real_trash_path == NULL)
+			real_trash_path = g_strdup ("");
+
+		if (g_ascii_strcasecmp (real_trash_path, folder_name) == 0)
+			folder->folder_flags |= CAMEL_FOLDER_IS_TRASH;
+
+		g_free (real_trash_path);
+	}
+
+	g_object_unref (settings);
+
 	return folder;
 }
 
