@@ -343,9 +343,8 @@ store_synchronize_sync (CamelStore *store,
                         GError **error)
 {
 	GPtrArray *folders;
-	CamelFolder *folder;
 	gboolean success = TRUE;
-	gint i;
+	gint ii;
 	GError *local_error = NULL;
 
 	if (expunge) {
@@ -353,27 +352,33 @@ store_synchronize_sync (CamelStore *store,
 		CamelFolderInfo *root, *fi;
 
 		folders = g_ptr_array_new ();
-		root = camel_store_get_folder_info_sync (store, NULL, CAMEL_STORE_FOLDER_INFO_RECURSIVE | CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL, NULL, NULL);
+		root = camel_store_get_folder_info_sync (
+			store, NULL,
+			CAMEL_STORE_FOLDER_INFO_RECURSIVE |
+			CAMEL_STORE_FOLDER_INFO_SUBSCRIBED |
+			CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL,
+			NULL, NULL);
 		fi = root;
-		while (fi) {
+		while (fi != NULL) {
 			CamelFolderInfo *next;
 
 			if ((fi->flags & CAMEL_FOLDER_NOSELECT) == 0) {
-				CamelFolder *fldr;
+				CamelFolder *folder;
 
-				fldr = camel_store_get_folder_sync (store, fi->full_name, 0, NULL, NULL);
-				if (fldr)
-					g_ptr_array_add (folders, fldr);
+				folder = camel_store_get_folder_sync (
+					store, fi->full_name, 0, NULL, NULL);
+				if (folder != NULL)
+					g_ptr_array_add (folders, folder);
 			}
 
 			/* pick the next */
 			next = fi->child;
-			if (!next)
+			if (next == NULL)
 				next = fi->next;
-			if (!next) {
+			if (next == NULL) {
 				next = fi->parent;
-				while (next) {
-					if (next->next) {
+				while (next != NULL) {
+					if (next->next != NULL) {
 						next = next->next;
 						break;
 					}
@@ -385,7 +390,7 @@ store_synchronize_sync (CamelStore *store,
 			fi = next;
 		}
 
-		if (root)
+		if (root != NULL)
 			camel_store_free_folder_info_full (store, root);
 	} else {
 		/* sync only folders opened until now */
@@ -395,10 +400,10 @@ store_synchronize_sync (CamelStore *store,
 	/* We don't sync any vFolders, that is used to update certain
 	 * vfolder queries mainly, and we're really only interested in
 	 * storing/expunging the physical mails. */
-	for (i = 0; i < folders->len; i++) {
-		folder = folders->pdata[i];
-		if (!CAMEL_IS_VEE_FOLDER (folder)
-		    && local_error == NULL) {
+	for (ii = 0; ii < folders->len; ii++) {
+		CamelFolder *folder = folders->pdata[ii];
+
+		if (!CAMEL_IS_VEE_FOLDER (folder) && local_error == NULL) {
 			camel_folder_synchronize_sync (
 				folder, expunge, cancellable, &local_error);
 			ignore_no_such_table_exception (&local_error);
@@ -1244,18 +1249,7 @@ camel_store_init (CamelStore *store)
 	g_rec_mutex_init (&store->priv->folder_lock);
 }
 
-GQuark
-camel_store_error_quark (void)
-{
-	static GQuark quark = 0;
-
-	if (G_UNLIKELY (quark == 0)) {
-		const gchar *string = "camel-store-error-quark";
-		quark = g_quark_from_static_string (string);
-	}
-
-	return quark;
-}
+G_DEFINE_QUARK (camel-store-error-quark, camel_store_error)
 
 /**
  * camel_store_folder_created:
