@@ -19,13 +19,12 @@
 /**
  * SECTION: e-collection-backend
  * @include: libebackend/libebackend.h
- * @short_description: An abstract base class for a data source
- *                     collection backend
+ * @short_description: A base class for a data source collection backend
  *
- * #ECollectionBackend is an abstract base class for backends which
- * manage a collection of data sources which collectively represent the
- * resources on a remote server.  The resources can include any number
- * of private and shared email stores, calendars and address books.
+ * #ECollectionBackend is a base class for backends which manage a
+ * collection of data sources that collectively represent the resources
+ * on a remote server.  The resources can include any number of private
+ * and shared email stores, calendars and address books.
  *
  * The backend's job is to synchronize local representations of remote
  * resources by adding and removing #EServerSideSource instances in an
@@ -83,7 +82,7 @@ enum {
 
 static guint signals[LAST_SIGNAL];
 
-G_DEFINE_ABSTRACT_TYPE (
+G_DEFINE_TYPE (
 	ECollectionBackend,
 	e_collection_backend,
 	E_TYPE_BACKEND)
@@ -653,7 +652,7 @@ collection_backend_constructed (GObject *object)
 
 static gboolean
 collection_backend_authenticate_sync (EBackend *backend,
-                                      ESourceAuthenticator *auth,
+                                      ESourceAuthenticator *authenticator,
                                       GCancellable *cancellable,
                                       GError **error)
 {
@@ -661,15 +660,16 @@ collection_backend_authenticate_sync (EBackend *backend,
 	ESourceRegistryServer *server;
 	EAuthenticationSession *session;
 	ESource *source;
-	const gchar *uid;
+	const gchar *source_uid;
 	gboolean success;
 
 	source = e_backend_get_source (backend);
-	uid = e_source_get_uid (source);
+	source_uid = e_source_get_uid (source);
 
 	collection_backend = E_COLLECTION_BACKEND (backend);
 	server = e_collection_backend_ref_server (collection_backend);
-	session = e_authentication_session_new (server, auth, uid);
+	session = e_source_registry_server_new_auth_session (
+		server, authenticator, source_uid);
 
 	success = e_source_registry_server_authenticate_sync (
 		server, session, cancellable, error);
@@ -720,6 +720,12 @@ collection_backend_child_added (ECollectionBackend *backend,
 	e_server_side_source_set_removable (
 		E_SERVER_SIDE_SOURCE (child_source), FALSE);
 
+	/* Collection children inherit the authentication session type. */
+	g_object_bind_property (
+		collection_source, "auth-session-type",
+		child_source, "auth-session-type",
+		G_BINDING_SYNC_CREATE);
+
 	/* Collection children inherit OAuth 2.0 support if available. */
 	g_object_bind_property (
 		collection_source, "oauth2-support",
