@@ -108,14 +108,17 @@ void		e_source_registry_server_add_source
 void		e_source_registry_server_remove_source
 						(ESourceRegistryServer *server,
 						 ESource *source);
-gboolean	e_source_registry_server_load_all
-						(ESourceRegistryServer *server,
-						 GError **error);
 gboolean	e_source_registry_server_load_directory
 						(ESourceRegistryServer *server,
 						 const gchar *path,
 						 ESourcePermissionFlags flags,
 						 GError **error);
+gboolean	e_source_registry_server_load_resource
+						(ESourceRegistryServer *server,
+						 GResource *resource,
+						 const gchar *path,
+						 ESourcePermissionFlags flags,
+						 GError **error);
 ESource *	e_source_registry_server_load_file
 						(ESourceRegistryServer *server,
 						 GFile *file,
@@ -143,6 +146,11 @@ ECollectionBackendFactory *
 		e_source_registry_server_ref_backend_factory
 						(ESourceRegistryServer *server,
 						 ESource *source);
+EAuthenticationSession *
+		e_source_registry_server_new_auth_session
+						(ESourceRegistryServer *server,
+						 ESourceAuthenticator *authenticator,
+						 const gchar *source_uid);
 gboolean	e_source_registry_server_authenticate_sync
 						(ESourceRegistryServer *server,
 						 EAuthenticationSession *session,
@@ -159,6 +167,12 @@ gboolean	e_source_registry_server_authenticate_finish
 						 GAsyncResult *result,
 						 GError **error);
 
+#ifndef EDS_DISABLE_DEPRECATED
+gboolean	e_source_registry_server_load_all
+						(ESourceRegistryServer *server,
+						 GError **error);
+#endif /* EDS_DISABLE_DEPRECATED */
+
 G_END_DECLS
 
 #endif /* E_SOURCE_REGISTRY_SERVER_H */
