@@ -73,10 +73,6 @@ gsize		e_strftime			(gchar *string,
 
 gchar **	e_util_slist_to_strv		(const GSList *strings);
 GSList *	e_util_strv_to_slist		(const gchar * const *strv);
-GSList *	e_util_copy_string_slist	(GSList *copy_to, const GSList *strings);
-GSList *	e_util_copy_object_slist	(GSList *copy_to, const GSList *objects);
-void		e_util_free_string_slist	(GSList *strings);
-void		e_util_free_object_slist	(GSList *objects);
 void		e_util_free_nullable_object_slist
 						(GSList *objects);
 void		e_queue_transfer		(GQueue *src_queue,
@@ -159,12 +155,21 @@ void		e_named_parameters_set		(ENamedParameters *parameters,
 						 const gchar *value);
 const gchar *	e_named_parameters_get		(const ENamedParameters *parameters,
 						 const gchar *name);
-gchar **        e_named_parameters_to_strv	(const ENamedParameters *parameters);
+gchar **	e_named_parameters_to_strv	(const ENamedParameters *parameters);
 gboolean	e_named_parameters_test		(const ENamedParameters *parameters,
 						 const gchar *name,
 						 const gchar *value,
 						 gboolean case_sensitively);
 
+#ifndef EDS_DISABLE_DEPRECATED
+void		e_util_free_string_slist	(GSList *strings);
+void		e_util_free_object_slist	(GSList *objects);
+GSList *	e_util_copy_string_slist	(GSList *copy_to,
+						 const GSList *strings);
+GSList *	e_util_copy_object_slist	(GSList *copy_to,
+						 const GSList *objects);
+#endif /* EDS_DISABLE_DEPRECATED */
+
 G_END_DECLS
 
 #endif /* E_DATA_SERVER_UTIL_H */
