@@ -46,7 +46,7 @@
 #define SECURE_METHOD "tls"
 
 struct _ESourceSecurityPrivate {
-	GMutex *property_lock;
+	GMutex property_lock;
 	gchar *method;
 };
 
@@ -116,7 +116,7 @@ source_security_finalize (GObject *object)
 
 	priv = E_SOURCE_SECURITY_GET_PRIVATE (object);
 
-	g_mutex_free (priv->property_lock);
+	g_mutex_clear (&priv->property_lock);
 
 	g_free (priv->method);
 
@@ -169,7 +169,7 @@ static void
 e_source_security_init (ESourceSecurity *extension)
 {
 	extension->priv = E_SOURCE_SECURITY_GET_PRIVATE (extension);
-	extension->priv->property_lock = g_mutex_new ();
+	g_mutex_init (&extension->priv->property_lock);
 }
 
 /**
@@ -214,12 +214,12 @@ e_source_security_dup_method (ESourceSecurity *extension)
 
 	g_return_val_if_fail (E_IS_SOURCE_SECURITY (extension), NULL);
 
-	g_mutex_lock (extension->priv->property_lock);
+	g_mutex_lock (&extension->priv->property_lock);
 
 	protected = e_source_security_get_method (extension);
 	duplicate = g_strdup (protected);
 
-	g_mutex_unlock (extension->priv->property_lock);
+	g_mutex_unlock (&extension->priv->property_lock);
 
 	return duplicate;
 }
@@ -246,11 +246,11 @@ e_source_security_set_method (ESourceSecurity *extension,
 
 	g_return_if_fail (E_IS_SOURCE_SECURITY (extension));
 
-	g_mutex_lock (extension->priv->property_lock);
+	g_mutex_lock (&extension->priv->property_lock);
 
 	if (extension->priv->method &&
 	    g_strcmp0 (extension->priv->method, method) == 0) {
-		g_mutex_unlock (extension->priv->property_lock);
+		g_mutex_unlock (&extension->priv->property_lock);
 		return;
 	}
 
@@ -260,7 +260,7 @@ e_source_security_set_method (ESourceSecurity *extension,
 	if (extension->priv->method == NULL)
 		extension->priv->method = g_strdup ("none");
 
-	g_mutex_unlock (extension->priv->property_lock);
+	g_mutex_unlock (&extension->priv->property_lock);
 
 	object = G_OBJECT (extension);
 	g_object_freeze_notify (object);
