@@ -24,6 +24,7 @@
 #define E_SOURCE_WEBDAV_H
 
 #include <libsoup/soup.h>
+#include <libedataserver/e-source-enums.h>
 #include <libedataserver/e-source-extension.h>
 
 /* Standard GObject macros */
@@ -57,6 +58,10 @@
 
 G_BEGIN_DECLS
 
+/* forward declaration */
+struct _ENamedParameters;
+struct _ESourceRegistry;
+
 typedef struct _ESourceWebdav ESourceWebdav;
 typedef struct _ESourceWebdavClass ESourceWebdavClass;
 typedef struct _ESourceWebdavPrivate ESourceWebdavPrivate;
@@ -103,11 +108,6 @@ gchar *		e_source_webdav_dup_email_address
 void		e_source_webdav_set_email_address
 						(ESourceWebdav *extension,
 						 const gchar *email_address);
-gboolean	e_source_webdav_get_ignore_invalid_cert
-						(ESourceWebdav *extension);
-void		e_source_webdav_set_ignore_invalid_cert
-						(ESourceWebdav *extension,
-						 gboolean ignore_invalid_cert);
 const gchar *	e_source_webdav_get_resource_path
 						(ESourceWebdav *extension);
 gchar *		e_source_webdav_dup_resource_path
@@ -122,9 +122,33 @@ gchar *		e_source_webdav_dup_resource_query
 void		e_source_webdav_set_resource_query
 						(ESourceWebdav *extension,
 						 const gchar *resource_query);
+const gchar *	e_source_webdav_get_ssl_trust	(ESourceWebdav *extension);
+gchar *		e_source_webdav_dup_ssl_trust	(ESourceWebdav *extension);
+void		e_source_webdav_set_ssl_trust	(ESourceWebdav *extension,
+						 const gchar *ssl_trust);
 SoupURI *	e_source_webdav_dup_soup_uri	(ESourceWebdav *extension);
 void		e_source_webdav_set_soup_uri	(ESourceWebdav *extension,
 						 SoupURI *soup_uri);
+ETrustPromptResponse
+		e_source_webdav_prepare_ssl_trust_prompt
+						(ESourceWebdav *extension,
+						 SoupMessage *message,
+						 struct _ESourceRegistry *registry,
+						 struct _ENamedParameters *parameters);
+void		e_source_webdav_store_ssl_trust_prompt
+						(ESourceWebdav *extension,
+						 SoupMessage *message,
+						 ETrustPromptResponse response);
+void		e_source_webdav_unset_temporary_ssl_trust
+						(ESourceWebdav *extension);
+
+#ifndef EDS_DISABLE_DEPRECATED
+gboolean	e_source_webdav_get_ignore_invalid_cert
+						(ESourceWebdav *extension);
+void		e_source_webdav_set_ignore_invalid_cert
+						(ESourceWebdav *extension,
+						 gboolean ignore_invalid_cert);
+#endif /* EDS_DISABLE_DEPRECATED */
 
 G_END_DECLS
 
