@@ -21,12 +21,17 @@
 #include <stdlib.h>
 #include <glib/gi18n.h>
 
-#ifdef ENABLE_MAINTAINER_MODE
+#if defined (ENABLE_MAINTAINER_MODE) && defined (HAVE_GTK)
 #include <gtk/gtk.h>
 #endif
 
 #include <libebackend/libebackend.h>
 
+#include "evolution-source-registry-resource.h"
+
+#define RESOURCE_PATH_RO_SOURCES "/org/gnome/evolution-data-server/ro-sources"
+#define RESOURCE_PATH_RW_SOURCES "/org/gnome/evolution-data-server/rw-sources"
+
 /* Forward Declarations */
 void evolution_source_registry_migrate_basedir (void);
 void evolution_source_registry_migrate_sources (void);
@@ -36,6 +41,73 @@ gboolean	evolution_source_registry_migrate_imap_to_imapx
 						 GKeyFile *key_file,
 						 const gchar *uid);
 
+static void
+evolution_source_registry_load_error (ESourceRegistryServer *server,
+                                      GFile *file,
+                                      const GError *error)
+{
+	gchar *uri = g_file_get_uri (file);
+
+	g_printerr (
+		"** Failed to load key file at '%s': %s\n",
+		uri, error->message);
+
+	g_free (uri);
+}
+
+static gboolean
+evolution_source_registry_load_all (ESourceRegistryServer *server,
+                                    GError **error)
+{
+	ESourcePermissionFlags flags;
+	GResource *resource;
+	const gchar *path;
+	gboolean success;
+
+	g_return_val_if_fail (E_IS_SOURCE_REGISTRY_SERVER (server), FALSE);
+
+	/* Load the user's sources directory first so that user-specific
+	 * data sources overshadow predefined data sources with identical
+	 * UIDs.  The 'local' data source is one such example. */
+
+	path = e_server_side_source_get_user_dir ();
+	flags = E_SOURCE_PERMISSION_REMOVABLE |
+		E_SOURCE_PERMISSION_WRITABLE;
+	success = e_source_registry_server_load_directory (
+		server, path, flags, error);
+	g_prefix_error (error, "%s: ", path);
+
+	if (!success)
+		return FALSE;
+
+	resource = evolution_source_registry_get_resource ();
+
+	path = RESOURCE_PATH_RO_SOURCES;
+	flags = E_SOURCE_PERMISSION_NONE;
+	success = e_source_registry_server_load_resource (
+		server, resource, path, flags, error);
+	g_prefix_error (error, "%s: ", path);
+
+	if (!success)
+		return FALSE;
+
+	path = RESOURCE_PATH_RW_SOURCES;
+	flags = E_SOURCE_PERMISSION_WRITABLE;
+	success = e_source_registry_server_load_resource (
+		server, resource, path, flags, error);
+	g_prefix_error (error, "%s: ", path);
+
+	if (!success)
+		return FALSE;
+
+	/* Signal that all files are now loaded.  One thing this
+	 * does is tell the cache-reaper module to start scanning
+	 * for orphaned cache directories. */
+	g_signal_emit_by_name (server, "files-loaded");
+
+	return TRUE;
+}
+
 gint
 main (gint argc,
       gchar **argv)
@@ -48,7 +120,7 @@ main (gint argc,
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
-#ifdef ENABLE_MAINTAINER_MODE
+#if defined (ENABLE_MAINTAINER_MODE) && defined (HAVE_GTK)
 	/* This is only to load gtk-modules, like
 	 * bug-buddy's gnomesegvhandler, if possible */
 	gtk_init_check (&argc, &argv);
@@ -69,6 +141,11 @@ reload:
 
 	server = e_source_registry_server_new ();
 
+	g_signal_connect (
+		server, "load-error", G_CALLBACK (
+		evolution_source_registry_load_error),
+		NULL);
+
 	/* Convert "imap" mail accounts to "imapx". */
 	g_signal_connect (
 		server, "tweak-key-file", G_CALLBACK (
@@ -76,7 +153,7 @@ reload:
 		NULL);
 
 	/* Failure here is fatal.  Don't even try to keep going. */
-	e_source_registry_server_load_all (
+	evolution_source_registry_load_all (
 		E_SOURCE_REGISTRY_SERVER (server), &error);
 
 	if (error != NULL) {
