@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright Copyright (C) 2012 Intel Corporation
+ * Copyright (C) 2012,2013 Intel Corporation
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -20,6 +20,7 @@
  *          Mathias Hasselmann <mathias@openismus.com>
  */
 
+#include <config.h>
 #include <stdlib.h>
 #include <libebook/libebook.h>
 
@@ -186,6 +187,20 @@ main (gint argc,
 		"/client/search/suffix/email", search_test,
 		e_book_query_field_test (E_CONTACT_EMAIL, E_BOOK_QUERY_ENDS_WITH, "jackson.com"),
 		2);
+#ifdef ENABLE_PHONENUMBER
+	add_client_test (
+		"/client/search/eqphone/exact/phone", search_test,
+		e_book_query_vcard_field_test(EVC_TEL, E_BOOK_QUERY_EQUALS_PHONE_NUMBER, "+1 221.542.3789"),
+		1);
+	add_client_test (
+		"/client/search/eqphone/national/phone", search_test,
+		e_book_query_vcard_field_test(EVC_TEL, E_BOOK_QUERY_EQUALS_NATIONAL_PHONE_NUMBER, "221.542.3789"),
+		1);
+	add_client_test (
+		"/client/search/eqphone/short/phone", search_test,
+		e_book_query_vcard_field_test(EVC_TEL, E_BOOK_QUERY_EQUALS_SHORT_PHONE_NUMBER, "5423789"),
+		1);
+#endif
 
 	/* Add search tests that fetch uids */
 	add_client_test (
