@@ -11,7 +11,7 @@ static ETestServerClosure book_closure =
 
 static void
 test_get_static_capabilities_sync (ETestServerFixture *fixture,
-				   gconstpointer       user_data)
+                                   gconstpointer user_data)
 {
 	EBook *book;
 	const gchar *caps;
@@ -31,8 +31,9 @@ main (gint argc,
 #endif
 	g_test_init (&argc, &argv, NULL);
 
-	g_test_add ("/EBook/GetStaticCapabilities/Sync", ETestServerFixture, &book_closure,
-		    e_test_server_utils_setup, test_get_static_capabilities_sync, e_test_server_utils_teardown);
+	g_test_add (
+		"/EBook/GetStaticCapabilities/Sync", ETestServerFixture, &book_closure,
+		e_test_server_utils_setup, test_get_static_capabilities_sync, e_test_server_utils_teardown);
 
 	return e_test_server_utils_run ();
 }
