@@ -172,21 +172,6 @@ ecal_test_utils_cal_get_cal_address (ECal *cal)
 	return address;
 }
 
-gchar *
-ecal_test_utils_cal_get_ldap_attribute (ECal *cal)
-{
-	GError *error = NULL;
-	gchar *attr = NULL;
-
-	if (!e_cal_get_ldap_attribute (cal, &attr, &error)) {
-		g_warning ("failed to get ldap attribute; %s\n", error->message);
-		exit (1);
-	}
-	test_print ("successfully got the ldap attribute\n");
-
-	return attr;
-}
-
 static const gchar *
 b2s (gboolean value)
 {
