@@ -20,7 +20,7 @@ static ETestServerClosure cal_closure =
 
 static void
 test_modify_object (ETestServerFixture *fixture,
-		    gconstpointer       user_data)
+                    gconstpointer user_data)
 {
 	ECal *cal;
 	ECalComponent *e_component;
@@ -74,8 +74,9 @@ main (gint argc,
 #endif
 	g_test_init (&argc, &argv, NULL);
 
-	g_test_add ("/ECal/ModifyObject", ETestServerFixture, &cal_closure,
-		    e_test_server_utils_setup, test_modify_object, e_test_server_utils_teardown);
+	g_test_add (
+		"/ECal/ModifyObject", ETestServerFixture, &cal_closure,
+		e_test_server_utils_setup, test_modify_object, e_test_server_utils_teardown);
 
 	return e_test_server_utils_run ();
 }
