@@ -12,7 +12,7 @@ static ETestServerClosure cal_closure =
 
 static void
 test_receive_objects (ETestServerFixture *fixture,
-		      gconstpointer       user_data)
+                      gconstpointer user_data)
 {
 	ECal *cal;
 	ECalComponent *e_component = NULL;
@@ -43,8 +43,9 @@ main (gint argc,
 #endif
 	g_test_init (&argc, &argv, NULL);
 
-	g_test_add ("/ECal/ReceiveObjects", ETestServerFixture, &cal_closure,
-		    e_test_server_utils_setup, test_receive_objects, e_test_server_utils_teardown);
+	g_test_add (
+		"/ECal/ReceiveObjects", ETestServerFixture, &cal_closure,
+		e_test_server_utils_setup, test_receive_objects, e_test_server_utils_teardown);
 
 	return e_test_server_utils_run ();
 }
