@@ -16,64 +16,17 @@
  *
  */
 
-#include "e-test-dbus-utils.h"
+#include "e-test-server-utils.h"
 
 #include <libedataserver/libedataserver.h>
 
-typedef struct _TestClosure TestClosure;
-typedef struct _TestFixture TestFixture;
-
-struct _TestClosure {
-	GTestDBus *test_dbus;
-	const gchar *base_directory;
-};
-
-struct _TestFixture {
-	ESourceRegistry *registry;
-	GMainLoop *main_loop;
-};
-
-static void
-test_fixture_setup_session (TestFixture *fixture,
-                            gconstpointer user_data)
-{
-	const TestClosure *closure = user_data;
-	GError *error = NULL;
-
-	g_assert (fixture->registry == NULL);
-	g_assert (fixture->main_loop == NULL);
-
-	g_test_dbus_up (closure->test_dbus);
-
-	fixture->registry = e_source_registry_new_sync (NULL, &error);
-	g_assert_no_error (error);
-
-	fixture->main_loop = g_main_loop_new (NULL, FALSE);
-}
-
-static void
-test_fixture_teardown_session (TestFixture *fixture,
-                               gconstpointer user_data)
-{
-	const TestClosure *closure = user_data;
-	GError *error = NULL;
-
-	g_object_unref (fixture->registry);
-	fixture->registry = NULL;
-
-	g_main_loop_unref (fixture->main_loop);
-	fixture->main_loop = NULL;
-
-	g_test_dbus_stop (closure->test_dbus);
-
-	e_test_clean_base_directories (&error);
-	g_assert_no_error (error);
-}
+static ETestServiceType test_closure = {
+	E_TEST_SERVER_NONE, NULL, 0, FALSE };
 
 static gboolean
 test_commit_source_idle_cb (gpointer user_data)
 {
-	TestFixture *fixture = user_data;
+	ETestServerFixture *fixture = user_data;
 	ESource *source;
 	gchar *uid;
 	GError *error = NULL;
@@ -106,25 +59,24 @@ test_commit_source_idle_cb (gpointer user_data)
 		g_test_fail ();
 	}
 
-	g_main_loop_quit (fixture->main_loop);
+	g_main_loop_quit (fixture->loop);
 
 	return FALSE;
 }
 
 static void
-test_commit_source (TestFixture *fixture,
+test_commit_source (ETestServerFixture *fixture,
                     gconstpointer user_data)
 {
 	g_test_bug ("685986");
 	g_idle_add (test_commit_source_idle_cb, fixture);
-	g_main_loop_run (fixture->main_loop);
+	g_main_loop_run (fixture->loop);
 }
 
 gint
 main (gint argc,
       gchar **argv)
 {
-	TestClosure closure;
 	gint retval;
 
 	g_type_init ();
@@ -132,17 +84,14 @@ main (gint argc,
 	g_test_init (&argc, &argv, NULL);
 	g_test_bug_base ("http://bugzilla.gnome.org/");
 
-	closure.base_directory = e_test_setup_base_directories ();
-	closure.test_dbus = e_test_setup_dbus_session ();
-
 	g_test_add (
 		"/e-source-registry-test/CommitSource",
-		TestFixture, &closure,
-		test_fixture_setup_session,
+		ETestServerFixture, &test_closure,
+		e_test_server_utils_setup,
 		test_commit_source,
-		test_fixture_teardown_session);
+		e_test_server_utils_teardown);
 
-	retval = g_test_run ();
+	retval = e_test_server_utils_run ();
 
 	/* XXX Something is leaking a GDBusConnection reference.
 	 *     Leave this disabled until I can track it down. */
